## $Id: interfaces.py 10794 2013-11-23 08:24:15Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""Customized interfaces of the university application package.
"""

from zope import schema
from waeup.kofa.applicants.interfaces import (
    IApplicantBaseData,
    AppCatCertificateSource, CertificateSource)
from waeup.kofa.schoolgrades import ResultEntryField
from waeup.kofa.interfaces import (
    SimpleKofaVocabulary, academic_sessions_vocab, validate_email)
from waeup.kofa.schema import FormattedDate, TextLineChoice
from waeup.kofa.students.vocabularies import nats_vocab, GenderSource
from waeup.kofa.applicants.interfaces import (
    contextual_reg_num_source,
    IApplicant, IApplicantEdit, IApplicantUpdateByRegNo)
from kofacustom.nigeria.applicants.interfaces import (
    LGASource, high_qual, high_grade, exam_types,
    INigeriaApplicantOnlinePayment,
    )
from kofacustom.ekodisco.interfaces import MessageFactory as _
from kofacustom.ekodisco.payments.interfaces import ICustomOnlinePayment

class ICustomApplicant(IApplicant):
    """An applicant.

    """

    course1 = schema.Choice(
        title = _(u'Desired Contract'),
        source = AppCatCertificateSource(),
        required = False,
        )
    course2 = schema.Choice(
        title = _(u'Not applicable'),
        source = AppCatCertificateSource(),
        required = False,
        )
    course_admitted = schema.Choice(
        title = _(u'Assigned Contract'),
        source = CertificateSource(),
        required = False,
        readonly = False,
        )
    perm_address = schema.Text(
        title = _(u'Customer Address'),
        required = False,
        )
    service_address = schema.Text(
        title = _(u'Service Address'),
        required = False,
        )

class ICustomApplicantEdit(IApplicantEdit):
    """An applicant interface for edit forms.

    Here we can repeat the fields from base data and set the
    `required` and `readonly` attributes to True to further restrict
    the data access. Or we can allow only certain certificates to be
    selected by choosing the appropriate source.

    We cannot omit fields here. This has to be done in the
    respective form page.
    """

    course1 = schema.Choice(
        title = _(u'Desired Contract'),
        source = AppCatCertificateSource(),
        required = True,
        )
    course2 = schema.Choice(
        title = _(u'Not applicable'),
        source = AppCatCertificateSource(),
        required = False,
        )
    course_admitted = schema.Choice(
        title = _(u'Assigned Contract'),
        source = CertificateSource(),
        required = False,
        readonly = True,
        )
    perm_address = schema.Text(
        title = _(u'Customer Address'),
        required = True,
        )
    service_address = schema.Text(
        title = _(u'Service Address'),
        required = True,
        )

class ICustomApplicantOnlinePayment(INigeriaApplicantOnlinePayment):
    """An applicant payment via payment gateways.

    """

class ICustomApplicantUpdateByRegNo(IApplicantUpdateByRegNo):
    """Representation of an applicant.

    Skip regular reg_number validation if reg_number is used for finding
    the applicant object.
    """
